searchData={"items":[{"type":"behaviour","title":"NamedSupervisedServer","doc":"A behaviour module for starting supervised GenServer that is named as `__MODULE__` by default or you can supply different name.\n\nWith the use of `NamedSupervisedServer`, you can avoid the need to add `c:start_link/1` function with `name: __MODULE__`\nto your module every time you write a new one. And if you need your own `c:start_link/1` function, you can override it.\n\nCompatible with PartitionSupervisor. Partition number added at the end of process name, `:partition` argument passed down to process `init`.","ref":"NamedSupervisedServer.html"},{"type":"behaviour","title":"Installation - NamedSupervisedServer","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `named_supervised_server` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:named_supervised_server, \"~> 0.1\"}\n  ]\nend\n```","ref":"NamedSupervisedServer.html#module-installation"},{"type":"behaviour","title":"Usage - NamedSupervisedServer","doc":"* Add `use NamedSupervisedServer` to your module.\n* See [`Examples`](#module-examples).\n\n> #### `use NamedSupervisedServer` {: .info}\n>\n> When you `use NamedSupervisedServer`, the NamedSupervisedServer module will:\n> * set `@behaviour NamedSupervisedServer`,\n> * add `use GenServer`,\n> * pass options passed to `use NamedSupervisedServer` to `use GenServer`,\n> * define a `c:start_link/1` function with `name: __MODULE__`, so your module does not need to define it\n> if you don't want a custom one.","ref":"NamedSupervisedServer.html#module-usage"},{"type":"behaviour","title":"Usage with PartitionSupervisor - NamedSupervisedServer","doc":"You must use `with_arguments` with `:partition` key:\n\n```elixir\nwith_arguments: fn [opts], partition ->\n  [Keyword.put(opts, :partition, partition)]\nend}\n```\n\nLike this:\n\n```elixir\nchildren = [\n  {PartitionSupervisor,\n  child_spec: {MyNamedServer, my_arg: \"Hello named server!\"},\n  name: MyNamedServerPartitionSupervisor,\n  with_arguments: fn [opts], partition ->\n    [Keyword.put(opts, :partition, partition)]\n  end},\n]\n\n{:ok, pid} = Supervisor.start_link(children, strategy: :one_for_one)\n```\n\nSee [`Examples`](#module-examples).","ref":"NamedSupervisedServer.html#module-usage-with-partitionsupervisor"},{"type":"behaviour","title":"Callbacks - NamedSupervisedServer","doc":"The following callbacks may be implemented by modules that use the `NamedSupervisedServer` behavior:\n\n- `c:start_link/1`: Starts a GenServer process linked to the current process.\n  This function is often used to start the server as part of a supervision tree.\n\n`c:start_link/1` callback should return one of the following values:\n\n- `{:ok, pid}`: The server was successfully created and initialized.\n\n- `:ignore`: The server should be ignored, and no further action is taken.\n\n- `{:error, {:already_started, pid}}`: A process with the specified name already exists.\n\n- `{:error, reason}`: The initialization of the server failed for the given reason.\n\n- `{:stop, reason}`: The process is terminated due to the provided reason.","ref":"NamedSupervisedServer.html#module-callbacks"},{"type":"behaviour","title":"Options - NamedSupervisedServer","doc":"`c:start_link/1` callback accept the following option:\n\n- `:name` (optional): Used for name registration as described in the \"Name Registration\" section\n  in the documentation for `GenServer`.","ref":"NamedSupervisedServer.html#module-options"},{"type":"behaviour","title":"Examples - NamedSupervisedServer","doc":"","ref":"NamedSupervisedServer.html#module-examples"},{"type":"behaviour","title":"Basic usage - NamedSupervisedServer","doc":"```elixir\niex> defmodule MyServer do\n...>  use NamedSupervisedServer\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>end\n...># Starting a supervised process\n...>{:ok, sup} = Supervisor.start_link([MyServer], strategy: :one_for_one)\n...>{_id, child, _type, _modules} = hd(Supervisor.which_children(sup))\n...>assert Process.whereis(MyServer) == child\n```","ref":"NamedSupervisedServer.html#module-basic-usage"},{"type":"behaviour","title":"With GenServer options - NamedSupervisedServer","doc":"```elixir\niex> defmodule TransientServer do\n...>  use NamedSupervisedServer, restart: :transient, shutdown: 10_000\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>end\n...># Starting a supervised process\n...>{:ok, sup} = Supervisor.start_link([TransientServer], strategy: :one_for_one)\n...>{:ok, chldspec} = :supervisor.get_childspec(sup, TransientServer)\n...>assert chldspec.restart == :transient\n...>assert chldspec.shutdown == 10_000\n...>{_id, child, _type, _modules} = hd(Supervisor.which_children(sup))\n...>assert Process.whereis(TransientServer) == child\n```","ref":"NamedSupervisedServer.html#module-with-genserver-options"},{"type":"behaviour","title":"Using a different name for the process - NamedSupervisedServer","doc":"```elixir\niex>defmodule NamedServer do\n...>  use NamedSupervisedServer\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>\n...>  @impl GenServer\n...>  def handle_call(:get_my_arg, _from, state) do\n...>    {:reply, {:ok, state[:my_arg]}, state}\n...>  end\n...>\n...>  def get_my_arg(pid) do\n...>    GenServer.call(pid, :get_my_arg)\n...>  end\n...>end\n...>\n...>children = [\n...>  {NamedServer, my_arg: \"Hello named server!\", name: :my_named_server}\n...>]\n...># Starting a named supervised process\n...>{:ok, _} = Supervisor.start_link(children, strategy: :one_for_one)\n...>\n...># Access the named process using its registered name\n...>{:ok, \"Hello named server!\"} = NamedServer.get_my_arg(:my_named_server)\n```","ref":"NamedSupervisedServer.html#module-using-a-different-name-for-the-process"},{"type":"behaviour","title":"With PartitionSupervisor - NamedSupervisedServer","doc":"```elixir\niex>defmodule MyNamedServer do\n...>  use NamedSupervisedServer\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>\n...>  @impl GenServer\n...>  def handle_call(:get_my_arg, _from, state) do\n...>    {:reply, {:ok, state[:my_arg]}, state}\n...>  end\n...>\n...>  @impl GenServer\n...>  def handle_call(:get_partition, _from, state) do\n...>    {:reply, {:ok, state[:partition]}, state}\n...>  end\n...>\n...>  def get_my_arg(pid) do\n...>    GenServer.call(pid, :get_my_arg)\n...>  end\n...>\n...>  def get_partition(pid) do\n...>    GenServer.call(pid, :get_partition)\n...>  end\n...>end\n...>\n...>children = [\n...>  {PartitionSupervisor,\n...>   child_spec: {MyNamedServer, my_arg: \"Hello named server!\", name: :my_named_server},\n...>   name: MyNamedServerPartitionSupervisor,\n...>   with_arguments: fn [opts], partition ->\n...>     [Keyword.put(opts, :partition, partition)]\n...>   end},\n...>]\n...># Starting a named supervised process\n...>{:ok, _} = Supervisor.start_link(children, strategy: :one_for_one)\n...>\n...># Access the named process using its registered name\n...>{:ok, \"Hello named server!\"} = MyNamedServer.get_my_arg(:my_named_server0)\n...># Partition number of process\n...>{:ok, 0} = MyNamedServer.get_partition(:my_named_server0)\n```","ref":"NamedSupervisedServer.html#module-with-partitionsupervisor"},{"type":"behaviour","title":"Custom start_link/1 - NamedSupervisedServer","doc":"```elixir\niex>defmodule CustomServer do\n...>  use NamedSupervisedServer\n...>\n...>  # Override start_link/1 to provide additional options\n...>  @impl NamedSupervisedServer\n...>  def start_link(args) when is_list(args) do\n...>    GenServer.start_link(__MODULE__, args, name: :custom_server)\n...>  end\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>end\n...>\n...># Starting a custom supervised GenServer process\n...>{:ok, sup} = Supervisor.start_link([CustomServer], strategy: :one_for_one)\n...>{_id, child, _type, _modules} = hd(Supervisor.which_children(sup))\n...>assert Process.whereis(:custom_server) == child\n```","ref":"NamedSupervisedServer.html#module-custom-start_link-1"},{"type":"behaviour","title":"References - NamedSupervisedServer","doc":"* `GenServer`\n* `Supervisor`","ref":"NamedSupervisedServer.html#module-references"},{"type":"callback","title":"NamedSupervisedServer.start_link/1","doc":"Starts a `NamedSupervisedServer` process linked to the current process that is named as `__MODULE__` by default or you can supply different name.\n\nThis is often used to start the `NamedSupervisedServer` as part of a supervision tree.\n\nOnce the server is started, the `init/1` function of the given is called\nwith `init_arg` as its argument to initialize the server. To ensure a\nsynchronized start-up procedure, this function does not return until `init/1`\nhas returned.\n\nNote that a `NamedSupervisedServer` started with `c:start_link/1` is linked to the\nparent process and will exit in case of crashes from the parent. The `NamedSupervisedServer`\nwill also exit due to the `:normal` reasons in case it is configured to trap\nexits in the `init/1` callback.","ref":"NamedSupervisedServer.html#c:start_link/1"},{"type":"callback","title":"Options - NamedSupervisedServer.start_link/1","doc":"- `:name` (optional): Used for name registration as described in the \"Name Registration\" section\n  in the documentation for `GenServer`.","ref":"NamedSupervisedServer.html#c:start_link/1-options"},{"type":"callback","title":"Return values - NamedSupervisedServer.start_link/1","doc":"If the server is successfully created and initialized, this function returns\n`{:ok, pid}`, where `pid` is the PID of the server. If a process with the\nspecified server name already exists, this function returns\n`{:error, {:already_started, pid}}` with the PID of that process.\n\nIf the `init/1` callback fails with `reason`, this function returns\n`{:error, reason}`. Otherwise, if it returns `{:stop, reason}`\nor `:ignore`, the process is terminated and this function returns\n`{:error, reason}` or `:ignore`, respectively.","ref":"NamedSupervisedServer.html#c:start_link/1-return-values"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}